GetObswellNumberSearchData
^^^^^^^^^^^^^^^^^^^^^^^^^^

`GetObswellNumberSearchData?OBSNUMBER=DAE005,CRB002,PWL012 <https://www.waterconnect.sa.gov.au/_layouts/15/dfw.sharepoint.wdd/WDDDMS.ashx/GetObswellNumberSearchData?OBSNUMBER=DAE005,CRB002,PWL012>`__

Returns a JSON array of objects:

.. code-block:: json

    [
      {
        "DHNO": 19126,
        "LAT": -34.9971836,
        "LON": 137.0390329,
        "MAPNUM": 632800028,
        "MAX_DEPTH": 21.85,
        "OBSNUMBER": "CRB002",
        "DRILL_DATE": "1963-12-05",
        "PURP_DESC": "OBS",
        "AQ_MON": "Qpcb",
        "SWL": 6.28,
        "YIELD": 1.26,
        "TDS": 1692,
        "STAT_DESC": "OPR",
        "CLASS": "WW",
        "NRM": "Northern & Yorke",
        "LOGDRILL": "N",
        "LITHOLOG": "Y",
        "CHEM": "Y",
        "WATER": "Y",
        "SAL": "Y",
        "OBSWELL": "Y",
        "STRATLOG": "N",
        "HSTRATLOG": "Y",
        "LATEST_SWL_DATE": "2015-02-26",
        "LATEST_SAL_DATE": "1975-03-05",
        "LATEST_YIELD_DATE": "1963-12-05",
        "OBSNETWORK": "NY_NP_STH",
        "SWLSTATUS": "C",
        "SALSTATUS": "N",
        "LATEST_OPEN_DEPTH": 20.74,
        "LATEST_OPEN_DATE": "2010-12-06"
      },
      {
        "NAME": "WAROOKA TWS 4",
        "DHNO": 19237,
        "LAT": -34.979581,
        "LON": 137.17983,
        "MAPNUM": 632800139,
        "MAX_DEPTH": 21.34,
        "OBSNUMBER": "PWL012",
        "DRILL_DATE": "1971-05-16",
        "PURP_DESC": "TWS",
        "AQ_MON": "L+Qpcb",
        "SWL": 4.52,
        "YIELD": 7.58,
        "TDS": 744,
        "STAT_DESC": "OPR",
        "CLASS": "WW",
        "NRM": "Northern & Yorke",
        "LOGDRILL": "Y",
        "LITHOLOG": "Y",
        "CHEM": "Y",
        "WATER": "Y",
        "SAL": "Y",
        "OBSWELL": "Y",
        "STRATLOG": "N",
        "HSTRATLOG": "Y",
        "LATEST_SWL_DATE": "2015-07-15",
        "LATEST_SAL_DATE": "2013-04-02",
        "LATEST_YIELD_DATE": "1971-05-16",
        "OBSNETWORK": "NY_NP_STH",
        "REPLACEUNITNUM": "6328-429",
        "SWLSTATUS": "C",
        "SALSTATUS": "C",
        "LATEST_OPEN_DEPTH": 21.34,
        "LATEST_OPEN_DATE": "1971-05-16"
      },
      {
        "NAME": "B 361",
        "DHNO": 28764,
        "LAT": -34.155353,
        "LON": 138.455916,
        "MAPNUM": 652900119,
        "MAX_DEPTH": 27.43,
        "OBSNUMBER": "DAE005",
        "DRILL_DATE": "1949-01-18",
        "PURP_DESC": "STK",
        "SWL": 22.15,
        "YIELD": 0.37,
        "TDS": 3753,
        "STAT_DESC": "OPR",
        "CLASS": "WW",
        "NRM": "Northern & Yorke",
        "LOGDRILL": "N",
        "LITHOLOG": "N",
        "CHEM": "N",
        "WATER": "Y",
        "SAL": "Y",
        "OBSWELL": "Y",
        "STRATLOG": "N",
        "HSTRATLOG": "N",
        "LATEST_SWL_DATE": "2010-03-11",
        "LATEST_SAL_DATE": "1995-09-18",
        "LATEST_YIELD_DATE": "1949-01-01",
        "OBSNETWORK": "NY_NP_STH",
        "SWLSTATUS": "H",
        "SALSTATUS": "H",
        "LATEST_OPEN_DEPTH": 26.4,
        "LATEST_OPEN_DATE": "1995-06-29"
      }
    ]
